@@ -21,6 +21,7 @@ except ImportError:
 
 
 class RecurrenceWidget(forms.Textarea):
+
     def __init__(self, attrs=None, **kwargs):
         self.js_widget_options = kwargs
         defaults = {'class': 'recurrence-widget'}
@@ -82,6 +83,8 @@ class RecurrenceField(forms.CharField):
             u'Max dates exceeded. The limit is %(limit)s'),
         'max_exdates_exceeded': _(
             u'Max exclusion dates exceeded. The limit is %(limit)s'),
+        'recurrence_required': _(
+            u'This field is required. Set either a recurrence rule or date.'),
     }
 
     def __init__(
@@ -196,6 +199,12 @@ class RecurrenceField(forms.CharField):
                 raise forms.ValidationError(
                     self.error_messages['invalid_frequency'])
 
+        if self.required:
+            if not recurrence_obj.rrules and not recurrence_obj.rdates and not recurrence_obj.exdates and not recurrence_obj.exrules:
+                raise forms.ValidationError(
+                    self.error_messages['recurrence_required']
+                )
+
         return recurrence_obj
 
 
@@ -209,11 +218,12 @@ def find_recurrence_i18n_js_catalog():
         return _recurrence_javascript_catalog_url
 
     # first try to use the dynamic form of the javascript_catalog view
-    try:
-        return urls.reverse(
-            i18n.javascript_catalog, kwargs={'packages': 'recurrence'})
-    except urls.NoReverseMatch:
-        pass
+    if hasattr(i18n, 'javascript_catalog'):
+        try:
+            return urls.reverse(
+                i18n.javascript_catalog, kwargs={'packages': 'recurrence'})
+        except urls.NoReverseMatch:
+            pass
 
     # then scan the entire urlconf for a javascript_catalague pattern
     # that manually selects recurrence as one of the packages to include
@@ -223,7 +233,7 @@ def find_recurrence_i18n_js_catalog():
                 match = check_urlpatterns(pattern.url_patterns)
                 if match:
                     return match
-            elif (pattern.callback == i18n.javascript_catalog and
+            elif (hasattr(i18n, 'javascript_catalog') and pattern.callback == i18n.javascript_catalog and
                   'recurrence' in pattern.default_args.get('packages', [])):
                 if pattern.name:
                     return urls.reverse(pattern.name)
